Matrix

Struct Matrix 

pub struct Matrix<T> {
    pub data: Vec<T>,
    pub row_size: usize,
    pub col_size: usize,
}
MxN Matrix

Fields

data: Vec<T>row_size: usizecol_size: usize

Implementations

Source

impl<T> Matrix<T>
where T: PartialOrd + Default + Copy + Mul<Output = T>,

pub fn relu(&self) -> Matrix<T>
where T: PartialOrd + Default + Copy,

Apply the ReLU activation function onto a Matrix

pub fn leaky_relu(&self, alpha: T) -> Matrix<T>
where T: PartialOrd + Default + Copy + Mul<Output = T>,

Apply the Leaky ReLU activation function onto a Matrix

pub fn relu_backward(&self) -> Matrix<T>
where T: Copy + PartialOrd + Default + Add<T, Output = T> + Mul<T, Output = T> + From<u8>,

Apply backward pass for the ReLU activation function onto a Matrix

pub fn gelu(&self) -> Matrix<T>
where T: Copy + PartialOrd + Default + From<f64> + Into<f64>,

Apply the GeLU activation function onto a Matrix NOTE: Smoother (near 0) than ReLU & potential for regularization effects.

Source

impl<T: Default + Clone> Matrix<T>

pub fn new(row_size: usize, col_size: usize) -> Self

Construct a new non-empty and sized Matrix

pub fn new_random(row_size: usize, col_size: usize) -> Self
where T: Random,

Construct a new non-empty and sized Matrix with random values of T

pub fn get(&self, row: usize, col: usize) -> Option<&T>

Try to get a reference to the value at a given row and column from the matrix

pub fn get_diagonal(&self) -> Vec<T>

Get a vector of the diagonal elements of the matrix

pub fn get_mut(&mut self, row: usize, col: usize) -> Option<&mut T>

Try to get a mutable reference to the value at a given row and column from the matrix

pub fn set(&mut self, row: usize, column: usize, value: T) -> bool

Try to set a value at a given row and column in the matrix

pub fn try_get_column(&self, column: usize) -> Option<Vec<T>>

Try to get all the values for a given column

NOTE: If you pass a column value larger than the number of columns this function will return None.

pub fn try_get_row(&self, row: usize) -> Option<Vec<T>>

Try to get all the values for a given row

NOTE: If you pass a row value larger than the number of rows this function will return None.

pub fn from_columns(cols: Vec<Vec<T>>) -> Matrix<T>

Create a Matrix from a columns (vec of vec)

pub fn sub_matrix(&self, skip_row: usize, skip_col: usize) -> Matrix<T>

Create a sub matrix with a specific row and column to exclude

pub fn transpose(&self) -> Matrix<T>

Perform a transpose operation (swap rows for columns and vice versa)

Source

impl<T> Matrix<T>
where T: Default + Clone + Add<Output = T>,

pub fn trace(&self) -> T

Perform the trace operation that computes the sum of all diagonal elements in the matrix.

NOTE: off-diagnonal elements do NOT contribute to the trace of the matrix, so 2 very different matrices can have the same trace.

pub fn sum(&self) -> T

Perform a summation over the matrix.

Source

impl<T> Matrix<T>
where T: Add<Output = T> + Sub<Output = T> + Mul<Output = T> + Clone + Default,

pub fn scalar_multiply(&self, scalar: T) -> Matrix<T>

Multiply a matrix by a single number (scalar) NOTE: The scalar type MUST match the matrix type.

pub fn multiply(&self, multiplier: &Matrix<T>) -> Option<Matrix<T>>

Multiply Matrix with another Matrix using standard matrix multiplication NOTE: The matrices inner dimensions MUST match else returns None

pub fn vector_multiply(&self, multiplier: &[T]) -> Option<Vec<T>>

Multiply the Matrix by a vector NOTE: The vectors length MUST match the vector columns, else returns None

pub fn determinant(&self) -> Option<T>

Compute a unique determinant for a Matrix NOTE: Only computable for square (M x M) matrices. NOTE: The determinant is 0 for a Matrix with rank r < M (non-invertable).

Source

impl<T> Matrix<T>
where T: Default + Clone + From<f64>,

pub fn identity(size: usize) -> Matrix<T>

Create an identity matrix of given size

Source

impl<T> Matrix<T>
where T: Default + Clone + Mul<Output = T> + Add<Output = T> + Into<f64>,

pub fn frobenius_norm(&self) -> f64

Compute the frobenius norm of a Matrix

Source

impl<T> Matrix<T>
where T: Copy + PartialOrd + Default + From<f64> + Into<f64> + Sub<Output = T> + Add<Output = T> + Mul<Output = T> + Div<Output = T> + Abs,

pub fn inverse(&self) -> Option<Matrix<T>>

Compute the inverse of a Matrix NOTE: Only computable for square (M x M) matrices. NOTE: Only computable for a Matrix where r = M (full rank).