pub trait Numeric: AsF64 { }Expand description
Marker trait for categorizing the set of all number types and enforcing type constraints.
pub trait Numeric: AsF64 { }Marker trait for categorizing the set of all number types and enforcing type constraints.